package de.hft.stuttgart.citydoctor2.healing;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import de.hft.stuttgart.citydoctor2.check.HealingID;
import de.hft.stuttgart.citydoctor2.check.HealingMethod;
import de.hft.stuttgart.citydoctor2.check.ModificationListener;
import de.hft.stuttgart.citydoctor2.check.error.RingTooFewPointsError;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing.LinearRingType;

public class HealTooFewPoints implements HealingMethod {
	
	private static final Logger logger = LogManager.getLogger(HealTooFewPoints.class);

	@Override
	public boolean visit(RingTooFewPointsError err, ModificationListener l) {
		logger.debug("Executing Repair for RingTooFewPointsError");
		LinearRing ring = err.getRing();
		// ring is only a line, remove ring
		if (ring.getType() == LinearRingType.INTERIOR) {
			ring.getParent().removeInnerRing(ring);
		} else {
			// remove whole polygon
			ring.getParent().remove();
		}
		return true;
	}

	@Override
	public HealTooFewPoints createNew() {
		return new HealTooFewPoints();
	}

	@Override
	public HealingID getID() {
		return HealingID.R_TOO_FEW_POINTS;
	}
	
}
